#
# Nessus CLI
# Copyright (C) <2023>  <Luke Minniear>
#

__title__ = 'lazy_nessus'
__description__ = 'Pause, resume, list, search for, check the status of, or export a Nessus scan. There is also the option to schedule a pause or resume action. Telegram bot support is also included.'
__version__ = '0.2.3'
